@@ -318,4 +318,4 @@ public class PlainJUnitResultFormatter implements JUnitResultFormatter, IgnoredT
             throw new BuildException("Unable to write output " + ex, ex);
         }
     }
-} // PlainJUnitResultFormatter
+}
